@@ -22,6 +22,10 @@
 #include <gnutls/gnutls.h>
 #include <gcrypt.h>
 
+#ifdef  _MSWINDOWS_
+#include <wincrypt.h>
+#endif
+
 #define NAMESPACE_LOCAL namespace __secure__ {
 #define LOCAL_NAMESPACE __secure__
 
